# coding: utf-8
# Copyright 2016 Vauxoo (https://www.vauxoo.com) <info@vauxoo.com>
# License LGPL-3.0 or later (http://www.gnu.org/licenses/lgpl).

from . import account_tax
from . import account_journal
from . import res_bank
from . import res_config_settings
from . import chart_template
